@@ -1,6 +1,5 @@
 package Bitcoin::Crypto::DerivationPath;
-$Bitcoin::Crypto::DerivationPath::VERSION = '3.999_1'; # TRIAL
-$Bitcoin::Crypto::DerivationPath::VERSION = '3.9991';
+$Bitcoin::Crypto::DerivationPath::VERSION = '3.001';
 use v5.10;
 use strict;
 use warnings;
@@ -12,8 +11,6 @@ use Types::Common -sigs, -types;
 use Bitcoin::Crypto::Constants;
 use Bitcoin::Crypto::Exception;
 
-use namespace::clean;
-
 has param 'private' => (
 	isa => Bool,
 );
@@ -59,9 +56,9 @@ sub get_path_hardened
 	];
 }
 
-signature_for from_string => (
-	method => Str,
-	positional => [Str],
+signature_for get_path_hardened => (
+	method => Object,
+	positional => [],
 );
 
 sub from_string
