@@ -1,6 +1,5 @@
 package Bitcoin::Crypto::Key::ExtPrivate;
-$Bitcoin::Crypto::Key::ExtPrivate::VERSION = '3.999_1'; # TRIAL
-$Bitcoin::Crypto::Key::ExtPrivate::VERSION = '3.9991';
+$Bitcoin::Crypto::Key::ExtPrivate::VERSION = '3.001';
 use v5.10;
 use strict;
 use warnings;
@@ -20,10 +19,28 @@ use Bitcoin::Crypto::Exception;
 
 use namespace::clean;
 
-extends qw(Bitcoin::Crypto::Key::ExtBase);
+with qw(Bitcoin::Crypto::Role::ExtendedKey);
 
 sub _is_private { 1 }
 
+sub generate_mnemonic
+{
+	shift;
+	carp 'Bitcoin::Crypto::Key::ExtPrivate->generate_mnemonic is deprecated.'
+		. ' Use generate_mnemonic function from Bitcoin::Crypto::Util instead.';
+
+	goto \&Bitcoin::Crypto::Util::generate_mnemonic;
+}
+
+sub mnemonic_from_entropy
+{
+	shift;
+	carp 'Bitcoin::Crypto::Key::ExtPrivate->mnemonic_from_entropy is deprecated.'
+		. ' Use mnemonic_from_entropy function from Bitcoin::Crypto::Util instead.';
+
+	goto \&Bitcoin::Crypto::Util::mnemonic_from_entropy;
+}
+
 signature_for from_mnemonic => (
 	method => Str,
 	positional => [Str, Maybe [Str], {default => ''}, Maybe [Str], {default => undef}],
@@ -152,6 +169,17 @@ sub _derive_key_partial
 	);
 }
 
+### DEPRECATED
+
+sub from_hex_seed
+{
+	my ($class, $seed) = @_;
+
+	carp "$class->from_hex_seed(\$seed) is now deprecated. Use $class->from_seed([hex => \$seed]) instead";
+
+	return $class->from_seed([hex => $seed]);
+}
+
 1;
 
 __END__
@@ -185,67 +213,43 @@ Bitcoin::Crypto::Key::ExtPrivate - Bitcoin extended private keys
 
 =head1 DESCRIPTION
 
-This class allows you to create an extended private key instance. Extended keys
-can be used to securely generate as many addresses as needed through key
-derivation. This allows for long-term, reusable wallet with a single backup.
+This class allows you to create an extended private key instance.
 
-Moreover, you can use an extended private key to:
+You can use an extended private key to:
 
 =over
 
 =item * generate extended public keys
 
-=item * derive extended keys using standard bip44 or a custom path
+=item * derive extended keys using a path
 
-=item * restore keys from mnemonic codes, seeds and serialized form
+=item * restore keys from mnemonic codes, seeds and base58 format
 
 =back
 
-=head1 INTERFACE
+see L<Bitcoin::Crypto::Network> if you want to work with other networks than
+Bitcoin Mainnet.
 
-=head2 Attributes
+=head1 METHODS
 
-=head3 network
-
-Instance of L<Bitcoin::Crypto::Network> - current network for this key. Can be
-coerced from network id. Default: current default network.
-
-I<writer:> C<set_network>
-
-=head3 purpose
-
-BIP44 purpose which was used to obtain this key. Filled automatically when
-deriving an extended key. If the key was not obtained through BIP44 derivation,
-this attribute is C<undef>.
-
-I<writer:> C<set_purpose>
-
-I<clearer:> C<clear_purpose>
-
-=head3 depth
-
-Integer - depth of derivation. Default: C<0> (master key)
-
-=head3 parent_fingerprint
-
-Bytestring of length 4 - fingerprint of the parent key. Default: four zero bytes
-
-=head3 child_number
-
-Integer - sequence number of the key on the current L</depth>. Default: C<0>
-
-=head3 chain_code
-
-Bytestring of length 32 - chain code of the extended key.
-
-=head2 Methods
-
-=head3 new
+=head2 new
 
 Constructor is reserved for internal and advanced use only. Use
 L</from_mnemonic>, L</from_seed> or L</from_serialized> instead.
 
-=head3 from_mnemonic
+=head2 generate_mnemonic
+
+	$mnemonic = $class->generate_mnemonic($len = 128, $lang = 'en')
+
+Deprecated - see L<Bitcoin::Crypto::Util/generate_mnemonic>.
+
+=head2 mnemonic_from_entropy
+
+	$mnemonic = $class->mnemonic_from_entropy($bytes, $lang = 'en')
+
+Deprecated - see L<Bitcoin::Crypto::Util/mnemonic_from_entropy>.
+
+=head2 from_mnemonic
 
 	$key_object = $class->from_mnemonic($mnemonic, $password = '', $lang = undef)
 
@@ -273,20 +277,28 @@ password. If there's a possibility of non-ascii, always use utf8 and set
 binmodes to get decoded (wide) characters to avoid problems recovering your
 wallet.
 
-=head3 from_seed
+=head2 from_seed
 
 	$key_object = $class->from_seed($seed)
 
 Creates and returns a new key from seed, which can be any data of any length.
 C<$seed> is expected to be a byte string.
 
-=head3 to_serialized
+=head2 from_hex_seed
+
+Deprecated. Use C<< $class->from_seed([hex => $seed]) >> instead.
+
+=head2 to_serialized
 
 	$serialized = $object->to_serialized()
 
 Returns the key serialized in format specified in BIP32 as byte string.
 
-=head3 from_serialized
+=head2 to_serialized_base58
+
+Deprecated. Use C<< to_format [base58 => $key->to_serialized] >> instead.
+
+=head2 from_serialized
 
 	$key_object = $class->from_serialized($serialized, $network = undef)
 
@@ -295,27 +307,33 @@ Tries to unserialize byte string C<$serialized> with format specified in BIP32.
 Dies on errors. If multiple networks match serialized data specify C<$network>
 manually (id of the network) to avoid exception.
 
-=head3 set_network
+=head2 from_serialized_base58
 
-	$object->set_network($val)
+Deprecated. Use C<< $class->from_serialized([base58 => $base58]) >> instead.
+
+=head2 set_network
+
+	$key_object = $object->set_network($val)
 
 Change key's network state to C<$val>. It can be either network name present in
 L<Bitcoin::Crypto::Network> package or an instance of this class.
 
-=head3 get_public_key
+Returns current key instance.
+
+=head2 get_public_key
 
 	$public_key_object = $object->get_public_key()
 
 Returns instance of L<Bitcoin::Crypto::Key::ExtPublic> generated from the
 private key.
 
-=head3 get_basic_key
+=head2 get_basic_key
 
 	$basic_key_object = $object->get_basic_key()
 
 Returns the key in basic format: L<Bitcoin::Crypto::Key::Private>
 
-=head3 derive_key
+=head2 derive_key
 
 	$derived_key_object = $object->derive_key($path)
 
@@ -326,7 +344,7 @@ See BIP32 document for details on derivation paths and methods.
 
 Returns a new extended key instance - result of a derivation.
 
-=head3 derive_key_bip44
+=head2 derive_key_bip44
 
 	$derived_key_object = $object->derive_key_bip44(%data)
 
@@ -342,7 +360,7 @@ checking.
 I<Note: coin_type parameter will be ignored, and the current network
 configuration set in the extended key will be used.>
 
-=head3 get_fingerprint
+=head2 get_fingerprint
 
 	$fingerprint = $object->get_fingerprint($len = 4)
 
@@ -374,7 +392,7 @@ L<Bitcoin::Crypto::Exception> namespace:
 
 =item L<Bitcoin::Crypto::Key::ExtPublic>
 
-=item L<Bitcoin::Crypto::Key::Private>
+=item L<Bitcoin::Crypto::Network>
 
 =back
 
