@@ -1,6 +1,5 @@
 package Bitcoin::Crypto::Key::ExtPublic;
-$Bitcoin::Crypto::Key::ExtPublic::VERSION = '3.999_1'; # TRIAL
-$Bitcoin::Crypto::Key::ExtPublic::VERSION = '3.9991';
+$Bitcoin::Crypto::Key::ExtPublic::VERSION = '3.001';
 use v5.10;
 use strict;
 use warnings;
@@ -15,7 +14,7 @@ use Bitcoin::Crypto::BIP44;
 
 use namespace::clean;
 
-extends qw(Bitcoin::Crypto::Key::ExtBase);
+with qw(Bitcoin::Crypto::Role::ExtendedKey);
 
 sub _is_private { 0 }
 
@@ -96,75 +95,37 @@ Bitcoin::Crypto::Key::ExtPublic - Bitcoin extended public keys
 
 =head1 DESCRIPTION
 
-This class allows you to create an extended public key instance. They are
-public counterparts to extended keys.
+This class allows you to create an extended public key instance.
 
 You can use an extended public key to:
 
 =over
 
-=item * derive extended keys using a path (only public keys, no hardened paths)
+=item * derive extended keys using a path (only public keys)
 
-=item * export and restore keys from the serialized format
+=item * restore keys from serialized base58 format
 
 =back
 
-Extended public keys pose a security risk: if the attacker obtains an extended
-public key and a single private key derived from the extended private key
-associated with the public key, they can obtain every private key on the same
-derivation path. For this reason, it is not recommended to share extended
-public keys.
+see L<Bitcoin::Crypto::Network> if you want to work with other networks than Bitcoin Mainnet.
 
-=head1 INTERFACE
+=head1 METHODS
 
-=head2 Attributes
-
-=head3 network
-
-Instance of L<Bitcoin::Crypto::Network> - current network for this key. Can be
-coerced from network id. Default: current default network.
-
-I<writer:> C<set_network>
-
-=head3 purpose
-
-BIP44 purpose which was used to obtain this key. Filled automatically when
-deriving an extended key. If the key was not obtained through BIP44 derivation,
-this attribute is C<undef>.
-
-I<writer:> C<set_purpose>
-
-I<clearer:> C<clear_purpose>
-
-=head3 depth
-
-Integer - depth of derivation. Default: C<0> (master key)
-
-=head3 parent_fingerprint
-
-Bytestring of length 4 - fingerprint of the parent key. Default: four zero bytes
-
-=head3 child_number
-
-Integer - sequence number of the key on the current L</depth>. Default: C<0>
-
-=head3 chain_code
-
-Bytestring of length 32 - chain code of the extended key.
-
-=head2 Methods
-
-=head3 new
+=head2 new
 
 Constructor is reserved for internal and advanced use only. Use L</from_serialized> instead.
 
-=head3 to_serialized
+=head2 to_serialized
 
 	$serialized_key = $object->to_serialized()
 
 Returns the key serialized in format specified in BIP32 as byte string.
 
-=head3 from_serialized
+=head2 to_serialized_base58
+
+Deprecated. Use C<< to_format [base58 => $key->to_serialized] >> instead.
+
+=head2 from_serialized
 
 	$key_object = $class->from_serialized($serialized, $network = undef)
 
@@ -173,13 +134,26 @@ Tries to unserialize byte string C<$serialized> with format specified in BIP32.
 Dies on errors. If multiple networks match serialized data specify C<$network>
 manually (id of the network) to avoid exception.
 
-=head3 get_basic_key
+=head2 from_serialized_base58
+
+Deprecated. Use C<< $class->from_serialized([base58 => $base58]) >> instead.
+
+=head2 set_network
+
+	$key_object = $object->set_network($val)
+
+Change key's network state to C<$val>. It can be either network name present in
+Bitcoin::Crypto::Network package or an instance of this class.
+
+Returns current key instance.
+
+=head2 get_basic_key
 
 	$basic_key_object = $object->get_basic_key()
 
 Returns the key in basic format: L<Bitcoin::Crypto::Key::Public>
 
-=head3 derive_key
+=head2 derive_key
 
 	$derived_key_object = $object->derive_key($path)
 
@@ -193,7 +167,7 @@ start with M (capital m).
 
 Returns a new extended key instance - result of a derivation.
 
-=head3 derive_key_bip44
+=head2 derive_key_bip44
 
 	$derived_key_object = $object->derive_key_bip44(%data)
 
@@ -202,7 +176,7 @@ calls L</derive_key> with it. In extended public keys, bip44 is always
 constructed with C<public> setting - it will always derive starting from
 account, effectively only using C<change> and C<index> attributes.
 
-=head3 get_fingerprint
+=head2 get_fingerprint
 
 	$fingerprint = $object->get_fingerprint($len = 4)
 
