@@ -1,6 +1,5 @@
 package Bitcoin::Crypto::Network;
-$Bitcoin::Crypto::Network::VERSION = '3.999_1'; # TRIAL
-$Bitcoin::Crypto::Network::VERSION = '3.9991';
+$Bitcoin::Crypto::Network::VERSION = '3.001';
 use v5.10;
 use strict;
 use warnings;
@@ -10,7 +9,6 @@ use Mooish::AttributeBuilder -standard;
 use Types::Common -sigs, -types;
 
 use Bitcoin::Crypto::Exception;
-use Bitcoin::Crypto::Types -types;
 
 use namespace::clean;
 
@@ -27,15 +25,15 @@ has param 'name' => (
 );
 
 has param 'p2pkh_byte' => (
-	coerce => ByteStrLen [1],
+	isa => StrLength [1, 1],
 );
 
 has param 'wif_byte' => (
-	coerce => ByteStrLen [1],
+	isa => StrLength [1, 1],
 );
 
 has param 'p2sh_byte' => (
-	coerce => ByteStrLen [1],
+	isa => StrLength [1, 1],
 	required => 0,
 );
 
