@@ -1,6 +1,5 @@
 package Bitcoin::Crypto::PSBT::Field;
-$Bitcoin::Crypto::PSBT::Field::VERSION = '3.999_1'; # TRIAL
-$Bitcoin::Crypto::PSBT::Field::VERSION = '3.9991';
+$Bitcoin::Crypto::PSBT::Field::VERSION = '3.001';
 use v5.10;
 use strict;
 use warnings;
@@ -50,11 +49,11 @@ sub BUILD
 		$self->_set_raw_key(undef);
 	}
 
-	if (defined $args->{value}) {
+	if (exists $args->{value}) {
 		$self->set_value($args->{value});
 	}
 
-	if (defined $args->{key}) {
+	if (exists $args->{key}) {
 		$self->set_key($args->{key});
 	}
 
