@@ -1,14 +1,11 @@
 package Bitcoin::Crypto::Role::Compressed;
-$Bitcoin::Crypto::Role::Compressed::VERSION = '3.999_1'; # TRIAL
-$Bitcoin::Crypto::Role::Compressed::VERSION = '3.9991';
+$Bitcoin::Crypto::Role::Compressed::VERSION = '3.001';
 use v5.10;
 use strict;
 use warnings;
 use Mooish::AttributeBuilder -standard;
 use Types::Common -sigs, -types;
 
-use Carp qw(carp);
-
 use Moo::Role;
 
 has param 'compressed' => (
@@ -19,19 +16,14 @@ has param 'compressed' => (
 
 signature_for set_compressed => (
 	method => Object,
-	positional => [Maybe [Bool], {default => undef}],
+	positional => [Bool, {default => !!1}],
 );
 
 sub set_compressed
 {
 	my ($self, $state) = @_;
 
-	carp 'set_compressed without argument is deprecated: use set_compressed(1) instead'
-		unless defined $state;
-
-	$self->_set_compressed($state // !!1);
-
-	# chainable - undocumented behavior, but kept for backcompat
+	$self->_set_compressed($state);
 	return $self;
 }
 
