@@ -1,6 +1,5 @@
 package Bitcoin::Crypto::Role::Network;
-$Bitcoin::Crypto::Role::Network::VERSION = '3.999_1'; # TRIAL
-$Bitcoin::Crypto::Role::Network::VERSION = '3.9991';
+$Bitcoin::Crypto::Role::Network::VERSION = '3.001';
 use v5.10;
 use strict;
 use warnings;
@@ -29,17 +28,16 @@ sub _trigger_network
 	if (Bitcoin::Crypto::Network->single_network) {
 		my $default = Bitcoin::Crypto::Network->get;
 		Bitcoin::Crypto::Exception::NetworkCheck->raise(
-			sprintf 'invalid network %s, running in single-network mode with %s', $self->network->id, $default->id
+			'invalid network, running in single-network mode with ' . $default->id
 		) if $default->id ne $self->network->id;
 	}
 }
 
+# make writer chainable
 sub set_network
 {
 	my ($self, $network) = @_;
 	$self->_set_network($network);
-
-	# chainable - undocumented behavior, but kept for backcompat
 	return $self;
 }
 
