@@ -1,6 +1,5 @@
 package Bitcoin::Crypto::Script::Recognition;
-$Bitcoin::Crypto::Script::Recognition::VERSION = '3.999_1'; # TRIAL
-$Bitcoin::Crypto::Script::Recognition::VERSION = '3.9991';
+$Bitcoin::Crypto::Script::Recognition::VERSION = '3.001';
 use v5.10;
 use strict;
 use warnings;
@@ -13,8 +12,6 @@ use Try::Tiny;
 
 use Bitcoin::Crypto::Script::Opcode;
 
-use namespace::clean;
-
 has param 'script' => (
 	isa => InstanceOf ['Bitcoin::Crypto::Script'],
 );
