@@ -1,6 +1,5 @@
 package Bitcoin::Crypto::Transaction::Sign;
-$Bitcoin::Crypto::Transaction::Sign::VERSION = '3.999_1'; # TRIAL
-$Bitcoin::Crypto::Transaction::Sign::VERSION = '3.9991';
+$Bitcoin::Crypto::Transaction::Sign::VERSION = '3.001';
 use v5.10;
 use strict;
 use warnings;
@@ -14,8 +13,6 @@ use Bitcoin::Crypto::Exception;
 use Bitcoin::Crypto::Constants;
 use Bitcoin::Crypto::Types -types;
 
-use namespace::clean;
-
 has param 'transaction' => (
 	isa => InstanceOf ['Bitcoin::Crypto::Transaction'],
 );
@@ -36,13 +33,9 @@ has option 'multisig' => (
 	coerce => Tuple [PositiveInt, PositiveInt],
 );
 
-has option 'sighash' => (
-	isa => PositiveOrZeroInt,
-	writer => -hidden,
-);
-
-has option 'script_tree' => (
-	coerce => BitcoinScriptTree,
+has param 'sighash' => (
+	isa => PositiveInt,
+	default => Bitcoin::Crypto::Constants::sighash_all,
 );
 
 has field 'input' => (
@@ -63,18 +56,15 @@ has field 'segwit' => (
 
 sub _get_signature
 {
-	my ($self, %args) = @_;
+	my ($self, $subscript) = @_;
 
-	my $digest = $self->transaction->get_digest_object(
+	my $digest = $self->transaction->get_digest(
 		signing_index => $self->signing_index,
-		($self->has_sighash ? (sighash => $self->sighash) : ()),
-		($args{signing_subscript} ? (signing_subscript => $args{signing_subscript}) : ()),
+		sighash => $self->sighash,
+		($subscript ? (signing_subscript => $subscript) : ()),
 	);
 
-	my $key = $args{key} // $self->key;
-	my $signature = $key->sign_message($digest->get_digest);
-
-	$self->_set_sighash($digest->sighash);
+	my $signature = $self->key->sign_message($digest);
 	$signature .= pack 'C', $self->sighash;
 
 	return $signature;
@@ -91,7 +81,7 @@ sub _get_old_signature
 		my $old_script = $self->input->signature_script->operations;
 		my @result;
 		foreach my $part (@$old_script) {
-			if ($part->[0]->name =~ /^OP_PUSH(DATA\d)?$/) {
+			if ($part->[0]->name =~ /^OP_PUSHDATA/) {
 
 				# using OP_PUSHDATA, as operations present most data pushes as this
 				push @result, $part->[2];
@@ -233,10 +223,7 @@ sub _sign_P2SH
 		$self->input->set_signature_script(
 			btc_script->new->push($segwit_nested->to_serialized)
 		);
-		$self->_sign_type(
-			$segwit_nested->type,
-			$self->_get_signature(signing_subscript => $segwit_nested->to_serialized)
-		);
+		$self->_sign_type($segwit_nested->type, $self->_get_signature($segwit_nested->to_serialized));
 	}
 	else {
 		die 'trying to sign payout from P2SH but no redeem_script was specified'
@@ -248,10 +235,7 @@ sub _sign_P2SH
 		die 'P2SH nested inside P2SH'
 			if $redeem_script->type eq 'P2SH';
 
-		$self->_sign_type(
-			$redeem_script->type,
-			$self->_get_signature(signing_subscript => $redeem_script->to_serialized)
-		);
+		$self->_sign_type($redeem_script->type, $self->_get_signature($redeem_script->to_serialized));
 		$self->input->signature_script->push($redeem_script->to_serialized);
 	}
 }
@@ -283,30 +267,10 @@ sub _sign_P2WSH
 	die 'P2WSH nested inside P2WSH'
 		if $redeem_script->type eq 'P2WSH';
 
-	$self->_sign_type($redeem_script->type, $self->_get_signature(signing_subscript => $redeem_script->to_serialized));
+	$self->_sign_type($redeem_script->type, $self->_get_signature($redeem_script->to_serialized));
 	$self->_set_signature([$redeem_script->to_serialized], !!1);
 }
 
-sub _sign_P2TR
-{
-	my ($self) = @_;
-
-	my $script_tree = $self->script_tree;
-
-	my $signature = $self->_get_signature(
-		key => $self->key->get_taproot_output_key(
-			$script_tree ? $script_tree->get_merkle_root : undef
-		),
-	);
-
-	# truncate sighash from signature to save 1 byte (required)
-	if ($self->sighash == Bitcoin::Crypto::Constants::sighash_default) {
-		$signature = substr $signature, 0, -1;
-	}
-
-	$self->_set_signature([$signature]);
-}
-
 sub _sign_type
 {
 	my ($self, $type, @rest) = @_;
