@@ -1,6 +1,5 @@
 package Bitcoin::Crypto::Transaction::UTXO;
-$Bitcoin::Crypto::Transaction::UTXO::VERSION = '3.999_1'; # TRIAL
-$Bitcoin::Crypto::Transaction::UTXO::VERSION = '3.9991';
+$Bitcoin::Crypto::Transaction::UTXO::VERSION = '3.001';
 use v5.10;
 use strict;
 use warnings;
@@ -164,10 +163,6 @@ inputs must be UTXOs. You need to register UTXOs before you can fully utilize a
 transaction. If a transaction has its UTXOs unregistered, its methods may raise
 an exception if they require full UTXO data.
 
-This module keeps an internal register of all valid UTXOs. You can add or
-remove UTXOs from this register, and they are accessed using two
-characteristics: transaction ID and output number (counted from 0).
-
 =head1 INTERFACE
 
 =head2 Attributes
@@ -249,8 +244,7 @@ Returns nothing. Passing undef disables the custom loader.
 Extracts all outputs from the C<$serialized_tx> (a bytestring). Same can be
 achieved by calling C<update_utxos> on a transaction object.
 
-Returns nothing. All C<$serialized_tx> outputs will be added to the register as
-new UTXO instances.
+Returns nothing.
 
 =head1 EXCEPTIONS
 
