@@ -1,6 +1,5 @@
 package Bitcoin::Crypto::Types;
-$Bitcoin::Crypto::Types::VERSION = '3.999_1'; # TRIAL
-$Bitcoin::Crypto::Types::VERSION = '3.9991';
+$Bitcoin::Crypto::Types::VERSION = '3.001';
 use v5.10;
 use strict;
 use warnings;
@@ -19,8 +18,7 @@ __PACKAGE__->add_type(
 		Enum->of(
 			Bitcoin::Crypto::Constants::bip44_purpose,
 			Bitcoin::Crypto::Constants::bip44_compat_purpose,
-			Bitcoin::Crypto::Constants::bip44_segwit_purpose,
-			Bitcoin::Crypto::Constants::bip44_taproot_purpose,
+			Bitcoin::Crypto::Constants::bip44_segwit_purpose
 		)
 	],
 );
@@ -61,41 +59,7 @@ my $bytestr = __PACKAGE__->add_type(
 );
 
 $bytestr->coercion->add_type_coercions(
-	$formatdesc, q{ Bitcoin::Crypto::Helpers::parse_formatdesc(@{$_}) },
-	HasMethods ['as_string'], q{ $_->as_string },
-);
-
-my $bytestrlen = __PACKAGE__->add_type(
-	name => 'ByteStrLen',
-	parent => $bytestr,
-
-	constraint_generator => sub {
-		my $len = shift;
-		PositiveInt->assert_valid($len);
-
-		return sub {
-			return length $_ == $len;
-		};
-	},
-
-	inline_generator => sub {
-		my $len = shift;
-
-		return sub {
-			my $varname = pop;
-
-			return (undef, qq{ length $varname == $len });
-		}
-	},
-
-	coercion_generator => sub {
-		return $bytestr->coercion;
-	},
-
-	message => sub {
-		my $len = shift;
-		return "Bytestring does not have length of $len";
-	},
+	$formatdesc, q{ Bitcoin::Crypto::Helpers::parse_formatdesc(@{$_}) }
 );
 
 my $scripttype = __PACKAGE__->add_type(
@@ -121,28 +85,6 @@ $script->coercion->add_type_coercions(
 	$bytestr->coercibles, q{ require Bitcoin::Crypto::Script; Bitcoin::Crypto::Script->from_serialized($_) },
 );
 
-my $script_tree = __PACKAGE__->add_type(
-	name => 'BitcoinScriptTree',
-	parent => InstanceOf->of('Bitcoin::Crypto::Script::Tree'),
-);
-
-$script_tree->coercion->add_type_coercions(
-	ArrayRef [ArrayRef | HashRef],
-	q{ require Bitcoin::Crypto::Script::Tree; Bitcoin::Crypto::Script::Tree->new(tree => $_) }
-);
-
-my $digest = __PACKAGE__->add_type(
-	name => 'BitcoinDigest',
-	parent => InstanceOf->of('Bitcoin::Crypto::Transaction::Digest::Result'),
-);
-
-$digest->coercion->add_type_coercions(
-	$bytestr->coercibles, q{
-		require Bitcoin::Crypto::Transaction::Digest::Result;
-		Bitcoin::Crypto::Transaction::Digest::Result->new(preimage => $_);
-	},
-);
-
 my $psbt_map_type = __PACKAGE__->add_type(
 	name => 'PSBTMapType',
 	parent => Enum->of(
@@ -168,8 +110,7 @@ __PACKAGE__->add_type(
 	parent => PositiveOrZeroInt,
 
 	constraint_generator => sub {
-		my $bits = shift;
-		PositiveInt->assert_valid($bits);
+		my $bits = PositiveInt->assert_valid(shift);
 
 		# for same bits as system, no need for special constraint
 		return sub { 1 }
@@ -242,12 +183,9 @@ Bitcoin::Crypto::Types - Bitcoin-specific data types
 		FormatStr
 		FormatDesc
 		ByteStr
-		ByteStrLen
 		ScriptType
 		ScriptDesc
 		BitcoinScript
-		BitcoinScriptTree
-		BitcoinDigest
 		PSBTMapType
 		PSBTFieldType
 		IntMaxBits
@@ -255,8 +193,6 @@ Bitcoin::Crypto::Types - Bitcoin-specific data types
 		DerivationPath
 	);
 
-	use Bitcoin::Crypto::Types -types;
-
 =head1 DESCRIPTION
 
 This module is a L<Type::Tiny> library for types which are either specific for
@@ -282,10 +218,6 @@ format.
 
 A string where each character is 8 bit. Can be coerced from L</FormatDesc>.
 
-=head2 ByteStrLen
-
-Same as L</ByteStr>, but can be parametrized to have a certain length.
-
 =head2 ScriptType
 
 A string with one of the available script type names, like C<P2WPKH>.
@@ -301,17 +233,6 @@ specific for that script type.
 An instance of L<Bitcoin::Crypto::Script>. Can be coerced from L</ScriptDesc>
 or L</ByteStr> (or any of its coercion types).
 
-=head2 BitcoinScriptTree
-
-An instance of L<Bitcoin::Crypto::Script::Tree>. Can be coerced from a
-structure by calling L<Bitcoin::Crypto::Script::Tree/new>
-implicitly.
-
-=head2 BitcoinDigest
-
-An instance of L<Bitcoin::Crypto::Transaction::Digest::Result>. Can be coerced
-from a bytestring (will be used as a preimage>.
-
 =head2 PSBTMapType
 
 A string with one of the available PSBT map type names, like C<global>.
